@@ -4,6 +4,8 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"strings"
+	"time"
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
@@ -11,6 +13,7 @@ import (
 	"github.com/superfly/flyctl/internal/client"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/pkg/flaps"
 	"github.com/superfly/flyctl/pkg/iostreams"
 )
@@ -65,7 +68,12 @@ func runMachineStatus(ctx context.Context) error {
 
 	machineBody, err := flapsClient.Get(ctx, machineID)
 	if err != nil {
-		return fmt.Errorf("machine %s could not be retrieved, %w", machineID, err)
+		switch {
+		case strings.Contains(err.Error(), "status"):
+			return fmt.Errorf("retrieve machine failed %s", err)
+		default:
+			return fmt.Errorf("machine %s could not be retrieved", machineID)
+		}
 	}
 	var machine api.V1Machine
 	err = json.Unmarshal(machineBody, &machine)
@@ -73,14 +81,22 @@ func runMachineStatus(ctx context.Context) error {
 		return fmt.Errorf("machine %s could not be retrieved", machineID)
 	}
 
-	machineLink := io.CreateLink("View it in the UI here:", fmt.Sprintf("https://fly.io/apps/%s/machines/%s", appName, machine.ID))
-
-	fmt.Fprintf(io.Out, "Success! A machine has been retrieved\n%s\n\n", machineLink)
+	eventLogs := [][]string{}
 
+	fmt.Fprintf(io.Out, "Success! A machine has been retrieved\n")
 	fmt.Fprintf(io.Out, " Machine ID: %s\n", machine.ID)
 	fmt.Fprintf(io.Out, " Instance ID: %s\n", machine.InstanceID)
-	fmt.Fprintf(io.Out, " State: %s\n", machine.State)
-	fmt.Fprintf(io.Out, " Region: %s\n", machine.Region)
-	fmt.Fprintf(io.Out, " Image: %s\n", machine.Config.Image)
+	fmt.Fprintf(io.Out, " State: %s\n\n", machine.State)
+	for _, event := range machine.Events {
+		timeInUTC := time.Unix(0, event.Timestamp*int64(time.Millisecond))
+		eventLogs = append(eventLogs, []string{
+			event.Status,
+			event.Type,
+			event.Source,
+			timeInUTC.Format(time.RFC3339Nano),
+		})
+	}
+	_ = render.Table(io.Out, "Event Logs", eventLogs, "Machine Status", "Event Type", "Source", "Timestamp")
+
 	return nil
 }
